aboutsummaryrefslogtreecommitdiff
path: root/src/backend/executor/nodeRecursiveunion.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/executor/nodeRecursiveunion.c')
-rw-r--r--src/backend/executor/nodeRecursiveunion.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/backend/executor/nodeRecursiveunion.c b/src/backend/executor/nodeRecursiveunion.c
index b577b72b50c..8bbec460173 100644
--- a/src/backend/executor/nodeRecursiveunion.c
+++ b/src/backend/executor/nodeRecursiveunion.c
@@ -39,23 +39,23 @@ build_hash_table(RecursiveUnionState *rustate)
/*
* If both child plans deliver the same fixed tuple slot type, we can tell
* BuildTupleHashTableExt to expect that slot type as input. Otherwise,
* we'll pass NULL denoting that any slot type is possible.
*/
- rustate->hashtable = BuildTupleHashTableExt(&rustate->ps,
- desc,
- ExecGetCommonChildSlotOps(&rustate->ps),
- node->numCols,
- node->dupColIdx,
- rustate->eqfuncoids,
- rustate->hashfunctions,
- node->dupCollations,
- node->numGroups,
- 0,
- rustate->ps.state->es_query_cxt,
- rustate->tableContext,
- rustate->tempContext,
- false);
+ rustate->hashtable = BuildTupleHashTable(&rustate->ps,
+ desc,
+ ExecGetCommonChildSlotOps(&rustate->ps),
+ node->numCols,
+ node->dupColIdx,
+ rustate->eqfuncoids,
+ rustate->hashfunctions,
+ node->dupCollations,
+ node->numGroups,
+ 0,
+ rustate->ps.state->es_query_cxt,
+ rustate->tableContext,
+ rustate->tempContext,
+ false);
}
@@ -39,23 +39,23 @@ build_hash_table(RecursiveUnionState *rustate)
/*
* If both child plans deliver the same fixed tuple slot type, we can tell
- * BuildTupleHashTableExt to expect that slot type as input. Otherwise,
+ * BuildTupleHashTable to expect that slot type as input. Otherwise,
* we'll pass NULL denoting that any slot type is possible.
*/